==> moyoung_ble_plugin-1.1.4.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/TrainHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHistoryTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingRealtimeInfo;
import com.crrepa.ble.conn.listener.CRPTrainingChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.TrainBean;

import java.util.ArrayList;
import java.util.List;

import io.flutter.plugin.common.MethodCall;

public class TrainHandler extends BaseConnectionEventChannelHandler {
    private static final TrainHandler instance = new TrainHandler();

    public static TrainHandler getInstance() {
        return instance;
    }

    // number表示要调用queryTraining方法的次数
    public int number = 0;
    public int id = 0;
    // isReturnAllData表示是否返回所有的锻炼数据
    public boolean isReturnAllData = false;
    public ArrayList<CRPTrainingInfo> arrayList = new ArrayList<>();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setTrainingListener(new CRPTrainingChangeListener() {
            @Override
            public void onHistoryTrainingChange(List<CRPHistoryTrainingInfo> historyTrainList) {
                if (eventSink == null) {
                    return;
                }
                if (arrayList.size() > 0) arrayList.clear();
                number = 0;
                id = 0;
                isReturnAllData = true;
                for (int i = 0; i < historyTrainList.size(); i++) {
                    if (historyTrainList.get(i).getStartTime() != 0) {
                        number++;
//                        这里不能循环调用，只能调用一次，循环调用数据会有出现数据一样的问题
                        if (number == 1) {
                            id = i;
                            connection.queryTraining(id);
                        }
                    }
                }
                TrainBean trainBean = new TrainBean();
                trainBean.setType(TrainBean.HISTORY_TRAINING_CHANGE);
                trainBean.setHistoryTrainList(historyTrainList);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTrainingChange(CRPTrainingInfo info) {
                if (eventSink == null) {
                    return;
                }
                if (number > 1) {
                    number--;
                    isReturnAllData = true;
                    arrayList.add(info);
                    connection.queryTraining(++id);
                } else {
                    if (isReturnAllData) {
                        number--;
                        isReturnAllData = false;
                    } else {
                        if (arrayList.size() > 0) arrayList.clear();
                    }
                    arrayList.add(info);
                    TrainBean trainBean = new TrainBean();
                    trainBean.setType(TrainBean.TRAINING_CHANGE);
                    trainBean.setTrainingList(arrayList);
                    String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                    new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
                }
            }

            @Override
            public void onRealtimeTrainingChange(CRPTrainingRealtimeInfo trainingRealtimeInfo) {

            }
        });
    }
}

==> moyoung_ble_plugin-1.1.6.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/TrainHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHistoryTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingRealtimeInfo;
import com.crrepa.ble.conn.listener.CRPTrainingChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.TrainBean;

import java.util.ArrayList;
import java.util.List;

import io.flutter.plugin.common.MethodCall;

public class TrainHandler extends BaseConnectionEventChannelHandler {
    private static final TrainHandler instance = new TrainHandler();

    public static TrainHandler getInstance() {
        return instance;
    }

    // number表示要调用queryTraining方法的次数
    public int number = 0;
    public int id = 0;
    // isReturnAllData表示是否返回所有的锻炼数据
    public boolean isReturnAllData = false;
    public ArrayList<CRPTrainingInfo> arrayList = new ArrayList<>();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setTrainingListener(new CRPTrainingChangeListener() {
            @Override
            public void onHistoryTrainingChange(List<CRPHistoryTrainingInfo> historyTrainList) {
                if (eventSink == null) {
                    return;
                }
                if (arrayList.size() > 0) arrayList.clear();
                number = 0;
                id = 0;
                isReturnAllData = true;
                for (int i = 0; i < historyTrainList.size(); i++) {
                    if (historyTrainList.get(i).getStartTime() > 1000000000000L) {
                        number++;
//                        这里不能循环调用，只能调用一次，循环调用数据会有出现数据一样的问题
                        if (number == 1) {
                            id = i;
                            connection.queryTraining(id);
                        }
                    }
                }
                TrainBean trainBean = new TrainBean();
                trainBean.setType(TrainBean.HISTORY_TRAINING_CHANGE);
                trainBean.setHistoryTrainList(historyTrainList);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTrainingChange(CRPTrainingInfo info) {
                if (eventSink == null) {
                    return;
                }
                if (number > 1) {
                    number--;
                    isReturnAllData = true;
                    arrayList.add(info);
                    connection.queryTraining(++id);
                } else {
                    if (isReturnAllData) {
                        number--;
                        isReturnAllData = false;
                    } else {
                        if (arrayList.size() > 0) arrayList.clear();
                    }
                    arrayList.add(info);
                    TrainBean trainBean = new TrainBean();
                    trainBean.setType(TrainBean.TRAINING_CHANGE);
                    trainBean.setTrainingList(arrayList);
                    String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                    new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
                }
            }

            @Override
            public void onRealtimeTrainingChange(CRPTrainingRealtimeInfo trainingRealtimeInfo) {

            }
        });
    }
}
